@@ -23,15 +23,14 @@
 #define DOLPHIN_MAINWINDOW_H
 
 #include <config-baloo.h>
-
 #include <kio/fileundomanager.h>
 #include <ksortablelist.h>
 #include <kxmlguiwindow.h>
-#include <QIcon>
-#include <QUrl>
 
+#include <QIcon>
 #include <QList>
 #include <QPointer>
+#include <QUrl>
 
 typedef KIO::FileUndoManager::CommandType CommandType;
 
@@ -46,6 +45,8 @@ class KJob;
 class KNewFileMenu;
 class QToolButton;
 class QIcon;
+class PlacesPanel;
+class TerminalPanel;
 
 /**
  * @short Main window for Dolphin.
@@ -56,11 +57,10 @@ class DolphinMainWindow: public KXmlGuiWindow
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.dolphin.MainWindow")
-    Q_PROPERTY(int id READ getId SCRIPTABLE true)
 
 public:
     DolphinMainWindow();
-    virtual ~DolphinMainWindow();
+    ~DolphinMainWindow() override;
 
     /**
      * Returns the currently active view.
@@ -90,6 +90,8 @@ public:
      */
     KNewFileMenu* newFileMenu() const;
 
+    void setTabsToHomeIfMountPathOpen(const QString& mountPath);
+
 public slots:
     /**
      * Pastes the clipboard data into the currently selected folder
@@ -98,11 +100,6 @@ public slots:
      */
     void pasteIntoFolder();
 
-    /**
-     * Returns the main window ID used through DBus.
-     */
-    int getId() const;
-
     /**
      * Implementation of the MainWindowAdaptor/QDBusAbstractAdaptor interface.
      * Inform all affected dolphin components (panels, views) of an URL
@@ -146,16 +143,16 @@ signals:
 
 protected:
     /** @see QWidget::showEvent() */
-    virtual void showEvent(QShowEvent* event) Q_DECL_OVERRIDE;
+    void showEvent(QShowEvent* event) override;
 
     /** @see QMainWindow::closeEvent() */
-    virtual void closeEvent(QCloseEvent* event) Q_DECL_OVERRIDE;
+    void closeEvent(QCloseEvent* event) override;
 
     /** @see KMainWindow::saveProperties() */
-    virtual void saveProperties(KConfigGroup& group) Q_DECL_OVERRIDE;
+    void saveProperties(KConfigGroup& group) override;
 
     /** @see KMainWindow::readProperties() */
-    virtual void readProperties(const KConfigGroup& group) Q_DECL_OVERRIDE;
+    void readProperties(const KConfigGroup& group) override;
 
 private slots:
     /**
@@ -255,6 +252,12 @@ private slots:
      */
     void togglePanelLockState();
 
+    /**
+     * Is invoked if the Terminal panel got visible/invisible and takes care
+     * that the active view has the focus if the Terminal panel is invisible.
+     */
+    void slotTerminalPanelVisibilityChanged();
+
     /** Goes back one step of the URL history. */
     void goBack();
 
@@ -267,28 +270,17 @@ private slots:
     /** Changes the location to the home URL. */
     void goHome();
 
-    /**
-     * Open the previous URL in the URL history in a new tab
-     * if the middle mouse button is clicked.
-     */
-    void goBack(Qt::MouseButtons buttons);
+    /** Open the previous URL in the URL history in a new tab. */
+    void goBackInNewTab();
 
-    /**
-     * Open the next URL in the URL history in a new tab
-     * if the middle mouse button is clicked.
-     */
-    void goForward(Qt::MouseButtons buttons);
+    /** Open the next URL in the URL history in a new tab. */
+    void goForwardInNewTab();
 
-    /**
-     * Open the URL one hierarchy above the current URL in a new tab
-     * if the middle mouse button is clicked.
-     */
-    void goUp(Qt::MouseButtons buttons);
+    /** Open the URL one hierarchy above the current URL in a new tab. */
+    void goUpInNewTab();
 
-    /**
-     * Open the home URL in a new tab
-     */
-    void goHome(Qt::MouseButtons buttons);
+    /** * Open the home URL in a new tab. */
+    void goHomeInNewTab();
 
     /** Opens Kompare for 2 selected files. */
     void compareFiles();
@@ -347,6 +339,11 @@ private slots:
      */
     void openInNewWindow();
 
+    /**
+     * Show the target of the selected symlink
+     */
+    void showTarget();
+
     /**
      * Indicates in the statusbar that the execution of the command \a command
      * has been finished.
@@ -420,11 +417,34 @@ private slots:
      */
     void setUrlAsCaption(const QUrl& url);
 
+    /**
+     * This slot is called when the user requested to unmount a removable media
+     * from the places menu
+     */
+    void slotStorageTearDownFromPlacesRequested(const QString& mountPath);
+
+    /**
+     * This slot is called when the user requested to unmount a removable media
+     * _not_ from the dolphin's places menu (from the notification area for e.g.)
+     * This slot is basically connected to each removable device's
+     * Solid::StorageAccess::teardownRequested(const QString & udi)
+     * signal through the places panel.
+     */
+    void slotStorageTearDownExternallyRequested(const QString& mountPath);
+
     /**
      * Is called when the view has finished loading the directory.
      */
     void slotDirectoryLoadingCompleted();
 
+    /**
+     * Is called when the user middle clicks a toolbar button.
+     *
+     * Here middle clicking Back/Forward/Up/Home will open the resulting
+     * folder in a new tab.
+     */
+    void slotToolBarActionMiddleClicked(QAction *action);
+
 private:
     void setupActions();
     void setupDockWidgets();
@@ -481,14 +501,13 @@ private:
     {
     public:
         UndoUiInterface();
-        virtual ~UndoUiInterface();
-        virtual void jobError(KIO::Job* job) Q_DECL_OVERRIDE;
+        ~UndoUiInterface() override;
+        void jobError(KIO::Job* job) override;
     };
 
     KNewFileMenu* m_newFileMenu;
     DolphinTabWidget* m_tabWidget;
     DolphinViewContainer* m_activeViewContainer;
-    int m_id;
 
     DolphinViewActionHandler* m_actionHandler;
     DolphinRemoteEncoding* m_remoteEncoding;
@@ -499,6 +518,10 @@ private:
     QTimer* m_updateToolBarTimer;
 
     KIO::Job* m_lastHandleUrlStatJob;
+
+    TerminalPanel* m_terminalPanel;
+    PlacesPanel* m_placesPanel;
+    bool m_tearDownFromPlacesRequested;
 };
 
 inline DolphinViewContainer* DolphinMainWindow::activeViewContainer() const
@@ -511,10 +534,5 @@ inline KNewFileMenu* DolphinMainWindow::newFileMenu() const
     return m_newFileMenu;
 }
 
-inline int DolphinMainWindow::getId() const
-{
-    return m_id;
-}
-
 #endif // DOLPHIN_MAINWINDOW_H
 
